# python-gen-trie

* 0.1.0 - Initial release to github
* 0.1.1 through 0.1.3 WIP releases
* 0.1.4 - First public release to PyPI
* 0.1.5 - Fix to install instructions
* 0.2.0 - Refactored internal node implementation
* 0.2.1 - Updated examples code
